@@ -1,5 +1,3 @@
-/* $XFree86$ */
-/* $XdotOrg: driver/xf86-video-sis/src/sis_video.h,v 1.4 2005/07/04 10:57:08 twini Exp $ */
 /*
  * Xv driver for SiS 300, 315 and 330 series.
  *
@@ -107,7 +105,8 @@ static void 	SISQueryBestSize(ScrnInfoPtr, Bool, short, short, short,
 			short, unsigned int *,unsigned int *, pointer);
 static int 	SISPutImage( ScrnInfoPtr,
 			short, short, short, short, short, short, short, short,
-			int, UChar *, short, short, Bool, RegionPtr, pointer);
+			int, UChar *, short, short, Bool, RegionPtr, pointer,
+			DrawablePtr);
 static int 	SISQueryImageAttributes(ScrnInfoPtr,
 			int, UShort *, UShort *, int *, int *);
 static void 	SISVideoTimerCallback(ScrnInfoPtr pScrn, Time now);
@@ -129,7 +128,8 @@ static void 	SISQueryBestSizeBlit(ScrnInfoPtr, Bool, short, short, short,
 			short, unsigned int *,unsigned int *, ULong);
 static int 	SISPutImageBlit( ScrnInfoPtr,
 			short, short, short, short, short, short, short, short,
-			int, UChar *, short, short, Bool, RegionPtr, ULong);
+			int, UChar *, short, short, Bool, RegionPtr, ULong,
+			DrawablePtr);
 static int 	SISQueryImageAttributesBlit(ScrnInfoPtr,
 			int, UShort *, UShort *, int *, int *);
 extern void     SISWriteBlitPacket(SISPtr pSiS, CARD32 *packet);
@@ -161,7 +161,7 @@ extern int	SISGetPortUtilAttribute(ScrnInfoPtr pScrn,  Atom attribute,
 #define IMAGE_MAX_WIDTH_315   1920
 #define IMAGE_MAX_WIDTH_340   1920	/* ? */
 #define IMAGE_MAX_WIDTH_761   1920	/* ? */
-#define IMAGE_MAX_HEIGHT_315  1080
+#define IMAGE_MAX_HEIGHT_315  1088
 
 #define OVERLAY_MIN_WIDTH       32  	/* Minimum overlay sizes */
 #define OVERLAY_MIN_HEIGHT      24
